@@ -5,14 +5,14 @@ package org.gcube.portlets.user.td.gwtservice.shared.monitor;
 
 import java.io.Serializable;
 
-import org.gcube.portlets.user.td.gwtservice.shared.UIOperationsId;
 import org.gcube.portlets.user.td.gwtservice.shared.task.TaskS;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.operations.UIOperationsId;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class OperationMonitor implements Serializable {
@@ -26,6 +26,7 @@ public class OperationMonitor implements Serializable {
 	private boolean abort;
 	private boolean hidden;
 	private TRId trId;
+	private String tabularResourceName;
 
 	
 	public OperationMonitor() {
@@ -93,15 +94,24 @@ public class OperationMonitor implements Serializable {
 	public void setHidden(boolean hidden) {
 		this.hidden = hidden;
 	}
+	
+	public String getTabularResourceName() {
+		return tabularResourceName;
+	}
+
+	public void setTabularResourceName(String tabularResourceName) {
+		this.tabularResourceName = tabularResourceName;
+	}
 
 	@Override
 	public String toString() {
 		return "OperationMonitor [taskId=" + taskId + ", operationId="
 				+ operationId + ", task=" + task + ", inBackground="
 				+ inBackground + ", abort=" + abort + ", hidden=" + hidden
-				+ ", trId=" + trId + "]";
+				+ ", trId=" + trId + ", tabularResourceName="
+				+ tabularResourceName + "]";
 	}
 
-	
+		
 	
 }
